@@ -13,8 +13,7 @@ else
 fi
 
 # set legacy iptables to allow kernels not supporting iptables-nft
-# CentOS has update-alternatives 1.13, so use --display (not --query)
-if $UPDATE_ALTERNATIVES --display iptables; then
+if $UPDATE_ALTERNATIVES --query iptables; then
     # NOTE(yoctozepto): Kolla-Ansible does not always set KOLLA_LEGACY_IPTABLES;
     # the workaround below ensures it gets set to `false` in such cases to fix
     # this code under `set -o nounset`.
