@@ -19,30 +19,28 @@ from oslo_config import types
 from kolla.version import version_info as version
 
 
-BASE_OS_DISTRO = ['centos', 'rhel', 'ubuntu', 'debian']
-BASE_ARCH = ['x86_64', 'ppc64le', 'aarch64']
+BASE_OS_DISTRO = ['centos', 'debian', 'ubuntu']
+BASE_ARCH = ['x86_64', 'aarch64']
 DEFAULT_BASE_TAGS = {
     'centos': {'name': 'quay.io/centos/centos', 'tag': 'stream8'},
-    'rhel': {'name': 'registry.access.redhat.com/ubi8', 'tag': 'latest'},
     'debian': {'name': 'debian', 'tag': 'bullseye'},
     'ubuntu': {'name': 'ubuntu', 'tag': '20.04'},
 }
 # NOTE(hrw): has to match PRETTY_NAME in /etc/os-release
 DISTRO_PRETTY_NAME = {
     'centos': 'CentOS Stream 8',
-    'rhel': 'Red Hat Enterprise Linux 8',
     'debian': 'Debian GNU/Linux 11 (bullseye)',
     'ubuntu': 'Ubuntu 20.04',
 }
-OPENSTACK_RELEASE = 'wallaby'
+OPENSTACK_RELEASE = 'xena'
 
 # This is noarch repository so we will use it on all architectures
-DELOREAN = "https://trunk.rdoproject.org/centos8-wallaby/" \
+DELOREAN = "https://trunk.rdoproject.org/centos8-xena/" \
     "consistent/delorean.repo"
-DELOREAN_DEPS = "https://trunk.rdoproject.org/centos8-wallaby/" \
+DELOREAN_DEPS = "https://trunk.rdoproject.org/centos8-xena/" \
     "delorean-deps.repo"
 
-INSTALL_TYPE_CHOICES = ['binary', 'source', 'rdo', 'rhos']
+INSTALL_TYPE_CHOICES = ['binary', 'source']
 
 # TODO(mandre) check for file integrity instead of downloading from an HTTPS
 # source
@@ -64,6 +62,7 @@ _PROFILE_OPTS = [
                     'mariadb',
                     'memcached',
                     'openvswitch',
+                    'proxysql',
                     'qdrouterd',
                     'rabbitmq',
                     'redis',
@@ -106,8 +105,6 @@ _PROFILE_OPTS = [
                     'monasca',
                     'murano',
                     'octavia',
-                    'panko',
-                    'rally',
                     'redis',
                     'sahara',
                     'senlin',
@@ -122,7 +119,6 @@ _PROFILE_OPTS = [
                 help='Aux Images'),
     cfg.ListOpt('default',
                 default=[
-                    'chrony',
                     'cron',
                     'kolla-toolbox',
                     'fluentd',
@@ -137,6 +133,7 @@ _PROFILE_OPTS = [
                     'neutron',
                     'nova-',
                     'placement',
+                    'proxysql',
                     'openvswitch',
                     'rabbitmq',
                 ],
@@ -205,7 +202,7 @@ _CLI_OPTS = [
                help='Format to write the final results in'),
     cfg.StrOpt('tarballs-base', default=TARBALLS_BASE,
                help='Base url to OpenStack tarballs'),
-    cfg.StrOpt('type', short='t', default='binary',
+    cfg.StrOpt('type', short='t', default='source',
                choices=INSTALL_TYPE_CHOICES,
                dest='install_type',
                help=('The method of the OpenStack install.')),
@@ -235,9 +232,14 @@ _CLI_OPTS = [
                       ' of disk IO. "docker-squash" tool is required, install'
                       ' it by "pip install docker-squash"')),
     cfg.StrOpt('openstack-release', default=OPENSTACK_RELEASE,
-               help='OpenStack release for building kolla-toolbox'),
-    cfg.StrOpt('openstack-branch', default='master',
-               help='Branch for source images'),
+               help='OpenStack release for building kolla source images and '
+                    'kolla-toolbox image'),
+    cfg.StrOpt('openstack-branch',
+               help='Branch for source images (internal; with a dash; '
+                    'please set openstack-release instead)'),
+    cfg.StrOpt('openstack-branch-slashed',
+               help='Branch for source images (internal; with a slash; '
+                    'please set openstack-release instead)'),
     cfg.BoolOpt('docker-healthchecks', default=True,
                 help='Add Kolla docker healthcheck scripts in the image'),
     cfg.BoolOpt('quiet', short='q', default=False,
@@ -247,9 +249,7 @@ _CLI_OPTS = [
     cfg.BoolOpt('summary', default=True,
                 help='Show summary at the end of build'),
     cfg.BoolOpt('infra-rename', default=False,
-                help='Rename infrastructure images to infra'),
-    cfg.StrOpt('repos-yaml', default='',
-               help='Path to alternative repos.yaml file'),
+                help='Rename infrastructure images to infra')
 ]
 
 _BASE_OPTS = [
@@ -306,10 +306,6 @@ SOURCES = {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ceilometer/'
                      'ceilometer-${openstack_branch}.tar.gz')},
-    'ceilometer-base-plugin-panko': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/panko/'
-                     'panko-${openstack_branch}.tar.gz')},
     'cinder-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cinder/'
@@ -507,7 +503,7 @@ SOURCES = {
     'monasca-thresh': {
         'type': 'url',
         'location': ('https://github.com/openstack/monasca-thresh/archive/'
-                     'master.tar.gz')},
+                     '${openstack_branch_slashed}.tar.gz')},
     'monasca-thresh-additions-monasca-common': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-common/'
@@ -568,98 +564,10 @@ SOURCES = {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ovn-octavia-provider/'
                      'ovn-octavia-provider-${openstack_branch}.tar.gz')},
-    'panko-base': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/panko/'
-                     'panko-${openstack_branch}.tar.gz')},
     'placement-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/placement/'
                      'placement-${openstack_branch}.tar.gz')},
-    'tempest-plugin-tempest-conf': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/python-tempestconf/'
-                     'python-tempestconf-master.tar.gz')},
-    'tempest-plugin-barbican': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/barbican-tempest-plugin/'
-                     'barbican_tempest_plugin-1.3.0.tar.gz')},
-    'tempest-plugin-blazar': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/blazar-tempest-plugin/'
-                     'blazar_tempest_plugin-0.6.1.tar.gz')},
-    'tempest-plugin-cinder': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/cinder-tempest-plugin/'
-                     'cinder-tempest-plugin-1.4.0.tar.gz')},
-    'tempest-plugin-ec2api': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/ec2api-tempest-plugin/'
-                     'ec2api-tempest-plugin-1.2.1.tar.gz')},
-    'tempest-plugin-heat': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/heat-tempest-plugin/'
-                     'heat-tempest-plugin-1.2.0.tar.gz')},
-    'tempest-plugin-ironic': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/ironic-tempest-plugin/'
-                     'ironic-tempest-plugin-2.2.0.tar.gz')},
-    'tempest-plugin-keystone': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/keystone-tempest-plugin/'
-                     'keystone_tempest_plugin-0.7.0.tar.gz')},
-    'tempest-plugin-magnum': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/magnum-tempest-plugin/'
-                     'magnum_tempest_plugin-1.3.0.tar.gz')},
-    'tempest-plugin-manila': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/manila-tempest-plugin/'
-                     'manila-tempest-plugin-1.4.0.tar.gz')},
-    'tempest-plugin-mistral': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/mistral-tempest-plugin/'
-                     'mistral_tempest_tests-1.2.0.tar.gz')},
-    'tempest-plugin-monasca': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/monasca-tempest-plugin/'
-                     'monasca-tempest-plugin-2.2.1.tar.gz')},
-    'tempest-plugin-murano': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/murano-tempest-plugin/'
-                     'murano-tempest-plugin-2.2.0.tar.gz')},
-    'tempest-plugin-neutron': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/neutron-tempest-plugin/'
-                     'neutron-tempest-plugin-1.4.0.tar.gz')},
-    'tempest-plugin-patrole': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/patrole/'
-                     'patrole-0.12.0.tar.gz')},
-    'tempest-plugin-telemetry': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/telemetry-tempest-plugin/'
-                     'telemetry_tempest_plugin-1.3.0.tar.gz')},
-    'tempest-plugin-trove': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/trove-tempest-plugin/'
-                     'trove_tempest_plugin-1.2.0.tar.gz')},
-    'tempest-plugin-vitrage': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/vitrage-tempest-plugin/'
-                     'vitrage-tempest-plugin-5.3.0.tar.gz')},
-    'tempest-plugin-watcher': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/watcher-tempest-plugin/'
-                     'watcher-tempest-plugin-2.2.0.tar.gz')},
-    'rally': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/rally/'
-                     'rally-3.2.0.tar.gz')},
-    'rally-plugin-openstack': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/rally-openstack/'
-                     'rally-openstack-2.1.0.tar.gz')},
     'sahara-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara/'
@@ -708,10 +616,6 @@ SOURCES = {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-sfc/'
                      'networking-sfc-${openstack_branch}.tar.gz')},
-    'tempest': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/tempest/'
-                     'tempest-27.0.0.tar.gz')},
     'trove-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove/'
@@ -762,10 +666,6 @@ USERS = {
         'uid': 42405,
         'gid': 42405,
     },
-    'chrony-user': {
-        'uid': 42406,
-        'gid': 42406,
-    },
     'cinder-user': {
         'uid': 42407,
         'gid': 42407,
@@ -860,7 +760,7 @@ USERS = {
     },
     'mongodb-user': {  # unused user (mongodb dropped)
         'uid': 42432,
-        'gid': 65534,
+        'gid': 42432,
     },
     'murano-user': {
         'uid': 42433,
@@ -882,15 +782,11 @@ USERS = {
         'uid': 42437,
         'gid': 42437,
     },
-    'panko-user': {
-        'uid': 42438,
-        'gid': 42438,
-    },
     'rabbitmq-user': {
         'uid': 42439,
         'gid': 42439,
     },
-    'rally-user': {
+    'rally-user': {  # unused user (rally dropped)
         'uid': 42440,
         'gid': 42440,
     },
@@ -1026,7 +922,7 @@ USERS = {
         'uid': 42479,
         'gid': 42479,
     },
-    'tempest-user': {
+    'tempest-user': {  # unused user (tempest dropped)
         'uid': 42480,
         'gid': 42480,
     },
@@ -1050,6 +946,10 @@ USERS = {
         'uid': 42486,
         'gid': 42486,
         'group': 'haclient',
+    },
+    'proxysql-user': {
+        'uid': 42487,
+        'gid': 42487,
     }
 }
 
@@ -1123,7 +1023,9 @@ def parse(conf, args, usage=None, prog=None,
     conf.set_default('base_tag', DEFAULT_BASE_TAGS[conf.base]['tag'])
     prefix = '' if conf.openstack_release == 'master' else 'stable-'
     openstack_branch = '{}{}'.format(prefix, conf.openstack_release)
+    openstack_branch_slashed = openstack_branch.replace('-', '/')
     conf.set_default('openstack_branch', openstack_branch)
+    conf.set_default('openstack_branch_slashed', openstack_branch_slashed)
 
     if not conf.base_image:
         conf.base_image = DEFAULT_BASE_TAGS[conf.base]['name']
